
* Stata codes to obtain unconditional and conditional standards for the Modified MMSE for Chinese 
* Adjust for education categories
* Age between 55 and 84  years (inclusive)
* Source data: Cheung et al., Unconditional and conditional standards using cognitive function curves for the Modified MMSE. 
*              Am J Geriat Psychiat 2014
 
************************************
* Instruction: specific the inputs *
************************************

* The Stata data file should strictly follow the specifications (A) to (C) 
* (A) In the data file, each row represents a participant
* (B) The data set contains six variables, named as: ID, education_level, age_T1, age_T2, MMSE_T1, MMSE_T1.
* 	  Annotation and admissible values for each of the five variables:
*	  ID: participant idenfication ID as specified by user. No requirement on the format of this variable.
*	  education_level: a categorical variable (0 or 1 or 2 or 3 or 4) indicating the education level of the participant. 
*                      Value lable:  0 ("no formal education"),  
*                                    1 ("primary school"), 
*                                    2 ("secondary school or equivalent"),  
*                                    3 ("pre-university or polytechnic"), 
*                                    4 ("university or above").       
*	  age_T1: Age at first assessment. A real value between 55 and 84 (inclusive).  
*	  age_T2: Age at second assessment. A real value between 55 and 84 (inclusive).  
*	  MMSE_T1: MMSE score at first assessment. An integer between 0 and 30 (inclusive). Non-integer will be rounded down. (e.g. 30.1 becomes 30)
*	  MMSE_T2: MMSE score at second assessment. An integer between 0 and 30 (inclusive). Non-integer will be rounded down. (e.g. 30.1 becomes 30) 
*      
* (C) If only age_T1 and/or age_T2 are specified, it gives unconditional percentiles and classification.
*     If age_T1, age_T2, MMSE_T1 and MMSE_T2 are all specified, it gives unconditional and conditional percentiles and classifications.

*****************************************
* Interpretation of variables generated *
*****************************************

* 18 variables will be generated and added to the data set:
* 5 variables named Uncond_05_T1, Uncond_10_T1, Uncond_25_T1, Uncond_50_T1, Uncond_75_T1 are the unconditional 5th, 10th, 25th, 50th and 75th percentiles. 
* 5 variables named Uncond_05_T2, Uncond_10_T2, Uncond_25_T2, Uncond_50_T2, Uncond_75_T2 contain the unconditional 5th, 10th, 25th, 50th and 75th percentiles. 
* 5 variables named Cond_05_T2, Cond_10_T2, Cond_25_T2, Cond_50_T2, Cond_75_T2 contain the conditional 5th, 10th, 25th, 50th and 75th percentiles, given the specified values for age_T1, age_T2 and MMSE_T1.
* variable Uncond_Cat_MMSE_T1 shows the classifcation by the unconditional percentiles for MMSE_T1 at age_T1. 
* variable Uncond_Cat_MMSE_T2 shows the classifcation by the unconditional percentiles for MMSE_T2 at age_T2. 
* variable Cond_Cat_MMSE_T2 shows the classification by the conditional percentiles for MMSE_T2 at age_T2 given MMSE_T1 at age_T1. 


*****************************************************************
* Read data file: users specify directory, folder and file name * 
*****************************************************************

* E.g. 
use sample_mmse, clear


****************************************
* Generate (un)conditional precentiles *
****************************************
mat uncond_coef=16.7906,-0.1047,0,6.6859,9.0838,9.5393,10.2356 ///
      \19.6551,-0.0651,-0.0023,5.1347,6.9927,7.954,7.9799      ///
	  \22.4002,-0.0368,-0.002,	3.7183,5.4671,6.4292,6.4375    ///
	  \25.2793,-0.0312,-0.0024,2.6211,3.6352,3.7777,4.2481     ///
	  \27,0,0,2,3,3,3
mat rownames uncond_coef=5th 10th 25th 50th 75th
mat colnames uncond_coef=Intercept Age Age2 Primary Secondary Pre-university University	
matlist uncond_coef
mat cond_coef=4.5383,-0.0391,-0.0038,0.814,1.4575,1.713,1.76,0.7072,0.0084 ///
   \7.1256,-0.0291,-0.0032,0.7918,1.4165,1.5417,1.5599,0.6479,0.0073       ///
   \11.2684,-0.0168,-0.0021,0.886,1.4508,1.6446,1.6528,0.5406,0.0086       ///
   \15.8354,-0.0104,-0.0017,0.6867,1.1137,1.1825,1.2269,0.4296,0.0062      ///
   \ 22.5297,-0.0027,-0.001,0.661,0.8572,0.8572,0.8767,0.2257,0.0041 
mat rownames cond_coef=5th 10th 25th 50th 75th
mat colnames cond_coef=Intercept Age Age2 Primary Secondary	Pre-university University Previous_MMSE	Interval_MMSE 
matlist cond_coef
label define cat_MMSE 1 "<5th Percentile" 2 ">5th Percentile and <10th Percentile" 3 ">10th Percentile and <25th Percentile"  ///
                      4 ">25th Percentile and <50th Percentile" 5 ">50th Percentile and <75th Percentile" 6 ">=75th Percentile",replace
*****
local pct=1
qui foreach varx in 05 10 25 50 75 {
gen Uncond_`varx'_T1=.
replace Uncond_`varx'_T1=uncond_coef[`pct',1]+uncond_coef[`pct',2]*(age_T1-65)+uncond_coef[`pct',3]*((age_T1-65)^2)  if age_T1<=84 & age_T1>=55
replace Uncond_`varx'_T1=Uncond_`varx'_T1+uncond_coef[`pct',4]  if education_level==1
replace Uncond_`varx'_T1=Uncond_`varx'_T1+uncond_coef[`pct',5]  if education_level==2
replace Uncond_`varx'_T1=Uncond_`varx'_T1+uncond_coef[`pct',6]  if education_level==3
replace Uncond_`varx'_T1=Uncond_`varx'_T1+uncond_coef[`pct',7]  if education_level==4  
replace Uncond_`varx'_T1=. if education_level>4  
replace Uncond_`varx'_T1=30 if Uncond_`varx'_T1>30 & Uncond_`varx'_T1~=.
replace Uncond_`varx'_T1=0  if Uncond_`varx'_T1<0 & Uncond_`varx'_T1~=.
format Uncond_`varx'_T1 %6.4f
local pct=`pct'+1
}

gen Uncond_Cat_MMSE_T1=1 if floor(MMSE_T1)<Uncond_05_T1 
replace Uncond_Cat_MMSE_T1=2 if floor(MMSE_T1)>Uncond_05_T1 & floor(MMSE_T1)<Uncond_10_T1
replace Uncond_Cat_MMSE_T1=3 if floor(MMSE_T1)>Uncond_10_T1 & floor(MMSE_T1)<Uncond_25_T1
replace Uncond_Cat_MMSE_T1=4 if floor(MMSE_T1)>Uncond_25_T1 & floor(MMSE_T1)<Uncond_50_T1
replace Uncond_Cat_MMSE_T1=5 if floor(MMSE_T1)>Uncond_50_T1 & floor(MMSE_T1)<Uncond_75_T1
replace Uncond_Cat_MMSE_T1=6 if floor(MMSE_T1)>=Uncond_75_T1 
replace Uncond_Cat_MMSE_T1=. if MMSE_T1==. | age_T1==. | floor(MMSE_T1)<0 | floor(MMSE_T1)>30 | age_T1>84 | age_T1<55 | (education_level>4 & education_level~=.) 
lab val Uncond_Cat_MMSE_T1 cat_MMSE

*****
local pct=1
qui foreach varx in 05 10 25 50 75 {
gen Uncond_`varx'_T2=.
replace Uncond_`varx'_T2=uncond_coef[`pct',1]+uncond_coef[`pct',2]*(age_T2-65)+uncond_coef[`pct',3]*((age_T2-65)^2)  if age_T2<=84 & age_T2>=55
replace Uncond_`varx'_T2=Uncond_`varx'_T2+uncond_coef[`pct',4]  if education_level==1
replace Uncond_`varx'_T2=Uncond_`varx'_T2+uncond_coef[`pct',5]  if education_level==2
replace Uncond_`varx'_T2=Uncond_`varx'_T2+uncond_coef[`pct',6]  if education_level==3
replace Uncond_`varx'_T2=Uncond_`varx'_T2+uncond_coef[`pct',7]  if education_level==4
replace Uncond_`varx'_T2=. if education_level>4  
replace Uncond_`varx'_T2=30 if Uncond_`varx'_T2>30 & Uncond_`varx'_T2~=.
replace Uncond_`varx'_T2=0  if Uncond_`varx'_T2<0 & Uncond_`varx'_T2~=.
format Uncond_`varx'_T2 %6.4f
local pct=`pct'+1
}

gen Uncond_Cat_MMSE_T2=1 if floor(MMSE_T2)<Uncond_05_T2 
replace Uncond_Cat_MMSE_T2=2 if floor(MMSE_T2)>Uncond_05_T2 & floor(MMSE_T2)<Uncond_10_T2
replace Uncond_Cat_MMSE_T2=3 if floor(MMSE_T2)>Uncond_10_T2 & floor(MMSE_T2)<Uncond_25_T2
replace Uncond_Cat_MMSE_T2=4 if floor(MMSE_T2)>Uncond_25_T2 & floor(MMSE_T2)<Uncond_50_T2
replace Uncond_Cat_MMSE_T2=5 if floor(MMSE_T2)>Uncond_50_T2 & floor(MMSE_T2)<Uncond_75_T2
replace Uncond_Cat_MMSE_T2=6 if floor(MMSE_T2)>=Uncond_75_T2 
replace Uncond_Cat_MMSE_T2=. if MMSE_T2==. | age_T2==. | floor(MMSE_T2)<0 | floor(MMSE_T2)>30 | age_T2>84 | age_T2<55 | (education_level>4 & education_level~=.)
lab val Uncond_Cat_MMSE_T2 cat_MMSE

*****
local pct=1
qui foreach varx in 05 10 25 50 75 {
gen Cond_`varx'_T2=.
replace Cond_`varx'_T2=cond_coef[`pct',1]+cond_coef[`pct',2]*(age_T2-65)+cond_coef[`pct',3]*((age_T2-65)^2)+(cond_coef[`pct',8]+cond_coef[`pct',9]*(age_T2-age_T1-2))*floor(MMSE_T1)  if age_T2<=84 & age_T2>=55 & age_T1<=84 & age_T1>=55 & floor(MMSE_T1)<=30 & floor(MMSE_T1)>=0
replace Cond_`varx'_T2=Cond_`varx'_T2+cond_coef[`pct',4]  if education_level==1
replace Cond_`varx'_T2=Cond_`varx'_T2+cond_coef[`pct',5]  if education_level==2
replace Cond_`varx'_T2=Cond_`varx'_T2+cond_coef[`pct',6]  if education_level==3
replace Cond_`varx'_T2=Cond_`varx'_T2+cond_coef[`pct',7]  if education_level==4
replace Cond_`varx'_T2=. if education_level>4 
replace Cond_`varx'_T2=30 if Cond_`varx'_T2>30 & Cond_`varx'_T2~=.
replace Cond_`varx'_T2=0  if Cond_`varx'_T2<0 & Cond_`varx'_T2~=.
format Cond_`varx'_T2 %6.4f
local pct=`pct'+1
}

gen Cond_Cat_MMSE_T2=1 if floor(MMSE_T2)<Cond_05_T2 
replace Cond_Cat_MMSE_T2=2 if floor(MMSE_T2)>Cond_05_T2 & floor(MMSE_T2)<Cond_10_T2
replace Cond_Cat_MMSE_T2=3 if floor(MMSE_T2)>Cond_10_T2 & floor(MMSE_T2)<Cond_25_T2
replace Cond_Cat_MMSE_T2=4 if floor(MMSE_T2)>Cond_25_T2 & floor(MMSE_T2)<Cond_50_T2
replace Cond_Cat_MMSE_T2=5 if floor(MMSE_T2)>Cond_50_T2 & floor(MMSE_T2)<Cond_75_T2
replace Cond_Cat_MMSE_T2=6 if floor(MMSE_T2)>=Cond_75_T2 
replace Cond_Cat_MMSE_T2=. if MMSE_T2==. | age_T2==. | floor(MMSE_T2)<0 | floor(MMSE_T2)>30 | age_T2>84 | age_T2<55 | floor(MMSE_T1)<0 | floor(MMSE_T1)>30 | age_T1>84 | age_T1<55 | (education_level>4 & education_level~=. )
lab val Cond_Cat_MMSE_T2 cat_MMSE

* End of file *
